@@ -112,7 +112,6 @@ class CortxJupyterSecretAccessKeyAuthentication(CortxJupyterAuthentication):
             secret_access_key=self.aws_secret_access_key,
             pre_auth_headers=self.pre_auth_headers,
         )
-    
 
 
 class CortxJupyter(ContentsManager):
@@ -308,7 +307,7 @@ def _file_exists(context, path):
     @gen.coroutine
     def key_exists():
         key = _key(context, path)
-        response = yield _head_object(context, context.s3_bucket, key)
+        response = _head_object(context, context.s3_bucket, key)
 
         return response
 
@@ -348,7 +347,7 @@ def _get_file_text(context, path, content):
 def _get_any(context, path, content, type, mimetype, format, decode):
     method = 'GET' if content else 'HEAD'
     key = _key(context, path)
-    response = yield _get_object(context, context.s3_bucket, key)
+    response = _get_object(context, context.s3_bucket, key)
 
     file_bytes = response.Body
     last_modified_str = response.LastModified
@@ -722,15 +721,14 @@ def _list_keys(context, key_prefix, delimiter):
     @gen.coroutine
     def _list_first_page():
         print(type(context.s3_bucket))
-        response = yield _list_objects(context, context.s3_bucket, key_prefix, delimiter, max_keys)
-
+        response = _list_objects(context, context.s3_bucket, key_prefix, delimiter, max_keys)
 
         return _parse_list_response(response)
 
     @gen.coroutine
     def _list_later_page(token):
 
-        response = yield _list_objects(context, context.s3_bucket, key_prefix, delimiter, max_keys, token)
+        response = _list_objects(context, context.s3_bucket, key_prefix, delimiter, max_keys, token)
 
         return _parse_list_response(response)
 
@@ -804,15 +802,11 @@ SAVERS = {
 
 # 'endpoint_url': AwsCreds.endpoint_url,
 
-def _initialize_context(context):
-    credentials = context.s3_auth()
-    return boto3.client('s3', aws_access_key_id=credentials.aws_access_key_id,
-                         aws_secret_access_key=credentials.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
-
-
 
 def _head_object(context, bucket, key):
-    s3_client = _initialize_context(context)
+    credentials = yield context.s3_auth()
+    s3_client = boto3.client('s3', aws_access_key_id=credentials.aws_access_key_id,
+                             aws_secret_access_key=credentials.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
     response = s3_client.head_object(Bucket=bucket, Key=key)
     if 'ContentLength' in response and response['ContentLength'] >= 0:
         return True
@@ -821,36 +815,46 @@ def _head_object(context, bucket, key):
 
 
 def _put_object(context, bucket, body, object_name):
-    s3_client = _initialize_context(context)
-    # Upload the file
+    credentials = yield context.s3_auth()
+    s3_client = boto3.client('s3', aws_access_key_id=credentials.aws_access_key_id,
+                             aws_secret_access_key=credentials.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")    # Upload the file
     return s3_client.put_object(Body=body, Bucket=bucket, Key=object_name)
 
 
 def _get_object(context, bucket, object_name):
-    s3_client = _initialize_context(context)
-    # Download the file
+    credentials = yield context.s3_auth()
+    s3_client = boto3.client('s3', aws_access_key_id=credentials.aws_access_key_id,
+                             aws_secret_access_key=credentials.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")    # Download the file
     return s3_client.get_object(Bucket=bucket, Key=object_name)
 
 
 def _list_buckets(context):
     # Retrieve the list of existing buckets
-    s3_client = _initialize_context(context)
-
+    credentials = yield context.s3_auth()
+    s3_client = boto3.client('s3', aws_access_key_id=credentials.aws_access_key_id,
+                             aws_secret_access_key=credentials.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
     return s3_client.list_buckets()
 
 
 def _copy_object(context, bucket, source_file, destination_file):
-    s3_client = _initialize_context(context)
+    credentials = yield context.s3_auth()
+    s3_client = boto3.client('s3', aws_access_key_id=credentials.aws_access_key_id,
+                             aws_secret_access_key=credentials.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
     return s3_client.copy_object(Bucket=bucket, CopySource=source_file, Key=destination_file)
 
 
 def _delete_object(context, bucket, file_name):
-    s3_client = _initialize_context(context)
+    credentials = yield context.s3_auth()
+    s3_client = boto3.client('s3', aws_access_key_id=credentials.aws_access_key_id,
+                             aws_secret_access_key=credentials.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
     return s3_client.delete_object(Bucket=bucket, Key=file_name)
 
 
 def _list_objects(context, bucket, prefix, delimiter, max_keys, token=''):
-    s3_client = _initialize_context(context)
+    credentials = yield context.s3_auth()
+    print(credentials)
+    s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
     return s3_client.list_objects_v2(
         Bucket=bucket,
         Delimiter=delimiter,
